==> emodpy_covid-0.0.32-py3-none-any.whl: emodpy_covid/config.py <==
#!/usr/bin/python3

# We expect this to be executed module-style (as a tool, not a script)
# This script creates a default covid-19 config, using emod_api

import sys
import json
import emod_api.schema.get_schema
import emod_api.config.default_from_schema as default
from emodpy_covid.mid.schema_to_class import ReadOnlyDict
from . import config1
from . import config2

def app( eradication_path ):
    get_schema.dtk_to_schema( eradication_path )
    default.write_default_from_schema()
    # default schema now stored as file on disk.
    # Let's load, replace some of the defaults with covid-19 settings and save.

    config = json.load( open( "default_config.json" ), object_hook=ReadOnlyDict )

    config = config1.set_params( config )
    # 1 param is not in schema so must be set outside of dict approach
    config = json.loads( json.dumps( config ) )
    config["parameters"]["Disable_IP_Whitelist"] = 1

    with open( "covid_config.json", "w" ) as config_file:
        json.dump( config, config_file, indent=4, sort_keys=True )

    # Now do stage1 config
    config = json.load( open( "default_config.json" ), object_hook=ReadOnlyDict )
    config = config2.set_params( config )
    config = json.loads( json.dumps( config ) )
    config["parameters"]["Disable_IP_Whitelist"] = 1

    with open( "covid_config_stage1.json", "w" ) as config_file:
        json.dump( config, config_file, indent=4, sort_keys=True )

if __name__ == "__main__":
    if len( sys.argv ) == 0:
        #print( "Usage: python3 -m emodpy-covid.config schema.json" )
        print( "Usage: python3 -m emodpy-covid.config /path/to/Eradication[.exe]" )
    else:
        app( sys.argv[1] )

==> emodpy_covid-0.0.50-py3-none-any.whl: emodpy_covid/config.py <==
#!/usr/bin/env python

# We expect this to be executed module-style (as a tool, not a script)
# This script creates a default covid-19 config, using emod_api

import sys
import json
import emod_api.schema.get_schema as get_schema
import emod_api.config.default_from_schema as default
from emodpy_covid.mid.schema_to_class import ReadOnlyDict
from . import config1
from . import config2

def app( eradication_path ):
    get_schema.dtk_to_schema( eradication_path )
    default.write_default_from_schema( "schema.json" )
    # default schema now stored as file on disk.
    # Let's load, replace some of the defaults with covid-19 settings and save.

    config = json.load( open( "default_config.json" ), object_hook=ReadOnlyDict )

    config = config1.set_params( config )
    # 1 param is not in schema so must be set outside of dict approach
    config = json.loads( json.dumps( config ) )
    config["parameters"]["Disable_IP_Whitelist"] = 1

    with open( "covid_config.json", "w" ) as config_file:
        json.dump( config, config_file, indent=4, sort_keys=True )

    # Now do stage1 config
    config = json.load( open( "default_config.json" ), object_hook=ReadOnlyDict )
    config = config2.set_params( config )
    config = json.loads( json.dumps( config ) )
    config["parameters"]["Disable_IP_Whitelist"] = 1

    with open( "covid_config_stage1.json", "w" ) as config_file:
        json.dump( config, config_file, indent=4, sort_keys=True )

if __name__ == "__main__":
    if len( sys.argv ) == 1:
        #print( "Usage: python3 -m emodpy-covid.config schema.json" )
        print( "Usage: python3 -m emodpy-covid.config /path/to/Eradication[.exe]" )
    else:
        app( sys.argv[1] )
